@@ -1,9 +1,10 @@
 from .bases import Pys
-from .constants import NTER_GENERAL, NUNR_LEFT
 from .position import PysPosition
 from .token import PysToken
 from .utils.decorators import typechecked, immutable
-from .utils.general import setimuattr
+from .utils.generic import setimuattr
+
+from typing import Literal
 
 @immutable
 class PysNode(Pys):
@@ -19,70 +20,99 @@ class PysNode(Pys):
 
 class PysNumberNode(PysNode):
 
-    __slots__ = ('token',)
+    __slots__ = ('value',)
 
     @typechecked
-    def __init__(self, token: PysToken) -> None:
-        super().__init__(token.position)
-        setimuattr(self, 'token', token)
+    def __init__(self, value: PysToken) -> None:
+        super().__init__(value.position)
+        setimuattr(self, 'value', value)
 
     def __repr__(self):
-        return f'Number(value={self.token.value!r})'
+        return f'Number(value={self.value!r})'
 
 class PysStringNode(PysNode):
 
-    __slots__ = ('token',)
+    __slots__ = ('value',)
 
     @typechecked
-    def __init__(self, token: PysToken) -> None:
-        super().__init__(token.position)
-        setimuattr(self, 'token', token)
+    def __init__(self, value: PysToken) -> None:
+        super().__init__(value.position)
+        setimuattr(self, 'value', value)
 
     def __repr__(self):
-        return f'String(value={self.token.value!r})'
+        return f'String(value={self.value!r})'
 
 class PysKeywordNode(PysNode):
 
-    __slots__ = ('token',)
+    __slots__ = ('name',)
 
     @typechecked
-    def __init__(self, token: PysToken) -> None:
-        super().__init__(token.position)
-        setimuattr(self, 'token', token)
+    def __init__(self, name: PysToken) -> None:
+        super().__init__(name.position)
+        setimuattr(self, 'name', name)
 
     def __repr__(self):
-        return f'Keyword(name={self.token.value!r})'
+        return f'Keyword(name={self.name!r})'
 
 class PysIdentifierNode(PysNode):
 
-    __slots__ = ('token',)
+    __slots__ = ('name',)
 
     @typechecked
-    def __init__(self, token: PysToken) -> None:
-        super().__init__(token.position)
-        setimuattr(self, 'token', token)
+    def __init__(self, name: PysToken) -> None:
+        super().__init__(name.position)
+        setimuattr(self, 'name', name)
 
     def __repr__(self):
-        return f'Identifier(name={self.token.value!r})'
+        return f'Identifier(name={self.name!r})'
 
-class PysSequenceNode(PysNode):
+class PysDictionaryNode(PysNode):
 
-    __slots__ = ('type', 'elements')
+    __slots__ = ('pairs',)
 
     @typechecked
-    def __init__(
-        self,
-        type: int,
-        elements: list[PysNode | PysToken | tuple[PysNode, PysNode]],
-        position: PysPosition
-    ) -> None:
+    def __init__(self, pairs: list[tuple[PysNode, PysNode]], position: PysPosition) -> None:
+        super().__init__(position)
+        setimuattr(self, 'pairs', tuple(pairs))
 
+    def __repr__(self):
+        return f'Dictionary(pairs={self.pairs!r})'
+
+class PysSetNode(PysNode):
+
+    __slots__ = ('elements',)
+
+    @typechecked
+    def __init__(self, elements: list[PysNode], position: PysPosition) -> None:
         super().__init__(position)
-        setimuattr(self, 'type', type)
         setimuattr(self, 'elements', tuple(elements))
 
     def __repr__(self):
-        return f'Sequence(type={self.type!r}, elements={self.elements!r})'
+        return f'Set(elements={self.elements!r})'
+
+class PysListNode(PysNode):
+
+    __slots__ = ('elements',)
+
+    @typechecked
+    def __init__(self, elements: list[PysNode], position: PysPosition) -> None:
+        super().__init__(position)
+        setimuattr(self, 'elements', tuple(elements))
+
+    def __repr__(self):
+        return f'List(elements={self.elements!r})'
+
+class PysTupleNode(PysNode):
+
+    __slots__ = ('elements',)
+
+    @typechecked
+    def __init__(self, elements: list[PysNode], position: PysPosition) -> None:
+        super().__init__(position)
+        setimuattr(self, 'elements', tuple(elements))
+
+    def __repr__(self):
+        return f'Tuple(elements={self.elements!r})'
 
 class PysAttributeNode(PysNode):
 
@@ -116,6 +146,25 @@ class PysSubscriptNode(PysNode):
     def __repr__(self):
         return f'Subscript(target={self.target!r}, slice={self.slice!r})'
 
+class PysCallNode(PysNode):
+
+    __slots__ = ('target', 'arguments')
+
+    @typechecked
+    def __init__(
+        self,
+        target: PysNode,
+        arguments: list[PysNode | tuple[PysToken, PysNode]],
+        position: PysPosition
+    ) -> None:
+
+        super().__init__(position)
+        setimuattr(self, 'target', target)
+        setimuattr(self, 'arguments', tuple(arguments))
+
+    def __repr__(self):
+        return f'Call(target={self.target!r}, arguments={self.arguments!r})'
+
 class PysChainOperatorNode(PysNode):
 
     __slots__ = ('operations', 'expressions')
@@ -141,10 +190,16 @@ class PysTernaryOperatorNode(PysNode):
     __slots__ = ('condition', 'valid', 'invalid', 'style')
 
     @typechecked
-    def __init__(self, condition: PysNode, valid: PysNode, invalid: PysNode, style: int) -> None:
+    def __init__(
+        self,
+        condition: PysNode,
+        valid: PysNode,
+        invalid: PysNode,
+        style: Literal['general', 'pythonic']
+    ) -> None:
         super().__init__(
             PysPosition(condition.position.file, condition.position.start, invalid.position.end)
-            if style == NTER_GENERAL else
+            if style == 'general' else
             PysPosition(condition.position.file, valid.position.start, invalid.position.end)
         )
 
@@ -156,7 +211,11 @@ class PysTernaryOperatorNode(PysNode):
     def __repr__(self):
         return (
             'TernaryOperator('
-            f'condition={self.condition!r}, valid={self.valid!r}, invalid={self.invalid!r}, style={self.style!r})'
+                f'condition={self.condition!r}, '
+                f'valid={self.valid!r}, '
+                f'invalid={self.invalid!r}, '
+                f'style={self.style!r}'
+            ')'
         )
 
 class PysBinaryOperatorNode(PysNode):
@@ -178,10 +237,10 @@ class PysUnaryOperatorNode(PysNode):
     __slots__ = ('operand', 'value', 'operand_position')
 
     @typechecked
-    def __init__(self, operand: PysToken, value: PysNode, operand_position: int) -> None:
+    def __init__(self, operand: PysToken, value: PysNode, operand_position: Literal['left', 'right']) -> None:
         super().__init__(
             PysPosition(operand.position.file, operand.position.start, value.position.end)
-            if operand_position == NUNR_LEFT else
+            if operand_position == 'left' else
             PysPosition(operand.position.file, value.position.start, operand.position.end)
         )
 
@@ -192,9 +251,24 @@ class PysUnaryOperatorNode(PysNode):
     def __repr__(self):
         return (
             'UnaryOperator('
-            f'operand={self.operand!r}, value={self.value!r}, operand_position={self.operand_position!r})'
+                f'operand={self.operand!r}, '
+                f'value={self.value!r}, '
+                f'operand_position={self.operand_position!r}'
+            ')'
         )
 
+class PysStatementsNode(PysNode):
+
+    __slots__ = ('body',)
+
+    @typechecked
+    def __init__(self, body: list[PysNode], position: PysPosition) -> None:
+        super().__init__(position)
+        setimuattr(self, 'body', tuple(body))
+
+    def __repr__(self):
+        return f'Statements(body={self.body!r})'
+
 class PysAssignNode(PysNode):
 
     __slots__ = ('target', 'operand', 'value')
@@ -217,13 +291,13 @@ class PysImportNode(PysNode):
     def __init__(
         self,
         name: tuple[PysToken, PysToken | None],
-        packages: list[tuple[PysToken, PysToken | None]] | int,
+        packages: list[tuple[PysToken, PysToken | None]] | Literal['all'],
         position: PysPosition
     ) -> None:
 
         super().__init__(position)
         setimuattr(self, 'name', name)
-        setimuattr(self, 'packages', packages if isinstance(packages, int) else tuple(packages))
+        setimuattr(self, 'packages', tuple(packages) if isinstance(packages, list) else packages)
 
     def __repr__(self):
         return f'Import(name={self.name!r}, packages={self.packages!r})'
@@ -300,17 +374,16 @@ class PysTryNode(PysNode):
 
 class PysWithNode(PysNode):
 
-    __slots__ = ('context', 'alias', 'body')
+    __slots__ = ('contexts', 'body')
 
     @typechecked
-    def __init__(self, context: PysNode, alias: PysToken | None, body: PysNode, position: PysPosition) -> None:
+    def __init__(self, contexts: list[tuple[PysNode, PysToken | None]], body: PysNode, position: PysPosition) -> None:
         super().__init__(position)
-        setimuattr(self, 'context', context)
-        setimuattr(self, 'alias', alias)
+        setimuattr(self, 'contexts', tuple(contexts))
         setimuattr(self, 'body', body)
 
     def __repr__(self):
-        return f'With(context={self.context!r}, alias={self.alias!r}, body={self.body!r})'
+        return f'With(contexts={self.contexts!r}, body={self.body!r})'
 
 class PysForNode(PysNode):
 
@@ -321,7 +394,7 @@ class PysForNode(PysNode):
         self,
         header: tuple[PysNode | None, PysNode | None, PysNode | None] |
                 tuple[PysNode, PysNode],
-        body: PysNode | None,
+        body: PysNode,
         else_body: PysNode | None,
         position: PysPosition
     ) -> None:
@@ -342,7 +415,7 @@ class PysWhileNode(PysNode):
     def __init__(
         self,
         condition: PysNode,
-        body: PysNode | None,
+        body: PysNode,
         else_body: PysNode | None,
         position: PysPosition
     ) -> None:
@@ -362,7 +435,7 @@ class PysDoWhileNode(PysNode):
     @typechecked
     def __init__(
         self,
-        body: PysNode | None,
+        body: PysNode,
         condition: PysNode,
         else_body: PysNode | None,
         position: PysPosition
@@ -425,24 +498,17 @@ class PysFunctionNode(PysNode):
             f'decorators={self.decorators!r}, name={self.name!r}, parameters={self.parameters!r}, body={self.body!r})'
         )
 
-class PysCallNode(PysNode):
+class PysGlobalNode(PysNode):
 
-    __slots__ = ('target', 'arguments')
+    __slots__ = ('identifiers',)
 
     @typechecked
-    def __init__(
-        self,
-        target: PysNode,
-        arguments: list[PysNode | tuple[PysToken, PysNode]],
-        position: PysPosition
-    ) -> None:
-
+    def __init__(self, identifiers: list[PysToken], position: PysPosition) -> None:
         super().__init__(position)
-        setimuattr(self, 'target', target)
-        setimuattr(self, 'arguments', tuple(arguments))
+        setimuattr(self, 'identifiers', tuple(identifiers))
 
     def __repr__(self):
-        return f'Call(target={self.target!r}, arguments={self.arguments!r})'
+        return f'Global(identifiers={self.identifiers!r})'
 
 class PysReturnNode(PysNode):
 
@@ -458,15 +524,23 @@ class PysReturnNode(PysNode):
 
 class PysThrowNode(PysNode):
 
-    __slots__ = ('target',)
+    __slots__ = ('target', 'cause')
 
     @typechecked
-    def __init__(self, target: PysNode, position: PysPosition) -> None:
-        super().__init__(PysPosition(position.file, position.start, target.position.end))
+    def __init__(self, target: PysNode, cause: PysNode | None, position: PysPosition) -> None:
+        super().__init__(
+            PysPosition(
+                position.file,
+                position.start,
+                target.position.end if cause is None else cause.position.end
+            )
+        )
+
         setimuattr(self, 'target', target)
+        setimuattr(self, 'cause', cause)
 
     def __repr__(self):
-        return f'Throw(target={self.target!r})'
+        return f'Throw(target={self.target!r}, cause={self.cause!r})'
 
 class PysAssertNode(PysNode):
 
@@ -481,6 +555,18 @@ class PysAssertNode(PysNode):
     def __repr__(self):
         return f'Assert(condition={self.condition!r}, message={self.message!r})'
 
+class PysDeleteNode(PysNode):
+
+    __slots__ = ('targets',)
+
+    @typechecked
+    def __init__(self, targets: list[PysNode], position: PysPosition) -> None:
+        super().__init__(position)
+        setimuattr(self, 'targets', tuple(targets))
+
+    def __repr__(self):
+        return f'Delete(targets={self.targets!r})'
+
 class PysEllipsisNode(PysNode):
 
     __slots__ = ()
